<template>
  <div class="invoice-form">
    <el-form label-width="120px">
        <el-form-item label="抬头类型：" :rules="{ required: true }">
          <el-radio-group v-model="source.invoiceInfo.titleType" class="ml-4 ">
            <el-radio :label="0" size="small">个人</el-radio>
            <el-radio :label="1" size="small">企业</el-radio>
          </el-radio-group>
        </el-form-item>
        <el-form-item label="发票类型：" :rules="{ required: true }">
          <el-select v-model="source.invoiceInfo.fapiaoType" class="w468">
            <el-option label="普通发票" :value="0" />
            <el-option label="专用发票" :value="1" :disabled="source.invoiceInfo.titleType === 0" />
          </el-select>
        </el-form-item>
        <el-form-item label="税号：" :rules="{ required: true }" v-if="source.invoiceInfo.titleType === 1">
          <el-input placeholder="请输入纳税识别号" class="w468" v-model="source.invoiceInfo.taxNo"></el-input>
        </el-form-item>
        <el-form-item label="发票抬头：" :rules="{ required: true }">
          <el-input placeholder="请输入发票抬头" class="w468" v-model="source.invoiceInfo.title"></el-input>
        </el-form-item>
        <el-form-item label="开户银行：" :rules="{ required: true }" v-if="source.invoiceInfo.titleType === 1 && source.invoiceInfo.fapiaoType === 1">
          <el-input placeholder="请输入开户银行" class="w468" v-model="source.invoiceInfo.bankName"></el-input>
        </el-form-item>
        <el-form-item label="银行账号：" :rules="{ required: true }" v-if="source.invoiceInfo.titleType === 1 && source.invoiceInfo.fapiaoType === 1">
          <el-input placeholder="请输入银行账号" class="w468" v-model="source.invoiceInfo.bankAccount"></el-input>
        </el-form-item>
        <el-form-item label="企业地址：" :rules="{ required: true }" v-if="source.invoiceInfo.titleType === 1 && source.invoiceInfo.fapiaoType === 1">
          <el-input placeholder="请输入企业地址" class="w468" v-model="source.invoiceInfo.address"></el-input>
        </el-form-item>
        <el-form-item label="企业电话：" :rules="{ required: true }" v-if="source.invoiceInfo.titleType === 1 && source.invoiceInfo.fapiaoType === 1">
          <el-input placeholder="请输入企业电话" class="w468" v-model="source.invoiceInfo.phone"></el-input>
        </el-form-item>
        <el-form-item>
          <div class="btns" :style="{ justifyContent: props.page === 'dialog' ? 'flex-end' : '' }">
            <div class="cancel-btn" @click="closeDialog">取消</div>
            <div :class="[props.page === 'dialog' ? 'confirm-btn' : 'submit-btn']" @click="submitInvoice">{{ props.page === 'dialog' ? '确定' : '提交' }}</div>
          </div>
        </el-form-item>
      </el-form>
  </div>
</template>

<script setup lang="ts">
import { reactive, watch } from 'vue';
import { ElMessage } from 'element-plus';
import { ConfigApi } from '/@/api/api';

interface Props {
  invoiceProps: Record<any, any>,
  type: string,
  page: string,
  showAddInvoiceHeaderDialog: boolean
}
const props = defineProps<Props>();
const emit = defineEmits(['closeDialog']);

const source = reactive({
  invoiceInfo: {
    titleType: 0,
    fapiaoType: 0,
    title: '',
    taxNo: '',
    address: '',
    bankAccount: '',
    bankName: '',
    // email: '',
    // isDefault: 0,
    phone: '',
  },
  invoiceHeaderList: [],
  limit: 10,
  page: 1,
  total: 0,
  totalPage: null,
});
source.invoiceInfo =  { ...source.invoiceInfo, ...props.invoiceProps };

watch(() => props.showAddInvoiceHeaderDialog, () => {
  props.type === 'edit' ? source.invoiceInfo =  { ...source.invoiceInfo, ...props.invoiceProps } : source.invoiceInfo = {
    titleType: 0,
    fapiaoType: 0,
    title: '',
    taxNo: '',
    address: '',
    bankAccount: '',
    bankName: '',
    phone: '',
  };
});

const closeDialog = ():void => {
  emit('closeDialog');
}

const validForm = (form: Record<any, any>):boolean => {
  if (!form.title) {
    ElMessage({
      message: '请输入发票抬头',
      type: 'warning',
      showClose: true
    });

    return false;
  }

  if (form.titleType === 1) {
    if (!form.taxNo) {
      ElMessage({
        message: '请输入纳税识别号',
        type: 'warning',
        showClose: true
      });

      return false;
    }

    if (form.fapiaoType === 1) {
      if (!form.bankName) {
        ElMessage({
          message: '请输入开户银行',
          type: 'warning',
          showClose: true
        });

        return false;
      }

      if (!form.bankAccount) {
        ElMessage({
          message: '请输入银行账号',
          type: 'warning',
          showClose: true
        });

        return false;
      }

      if (!form.address) {
        ElMessage({
          message: '请输入企业地址',
          type: 'warning',
          showClose: true
        });

        return false;
      }

      if (!form.phone) {
        ElMessage({
          message: '请输入手机号',
          type: 'warning',
          showClose: true
        });

        return false;
      }

      // const regPhone = /^1[3456789]\d{9}$/;
	  // 匹配手机号码
	  // const mobileNumberRegex = /^1[3456789]\d{9}$/;
	  // 匹配固定电话号码（包括区号和分机号）
	  const landlineNumberRegex = /^400-[0-9]{3}-[0-9]{4}|^1[34578]\d{9}$|^800-[0-9]{3}-[0-9]{4}/;
	  // console.log(mobileNumberRegex.test(form.phone))
	  console.log(landlineNumberRegex.test(form.phone))
      if (!landlineNumberRegex.test(form.phone)) {
        ElMessage({
          message: '请输入正确的手机号',
          type: 'warning',
          showClose: true
        });

        return false;
      }
    }
  }

  return true;
}

const submitInvoice = ():void => {
  console.info('submit', props.type);

  if (!validForm(source.invoiceInfo)) {
    return;
  }

  ConfigApi().addInvoiceHeaderApi(source.invoiceInfo, props.type).then(res => {
    let { code, message } = res;

    if (code !== 200) {
      ElMessage.error(message);
      return;
    }

    ElMessage({
      message: props.type === 'edit' ? '修改成功' : '添加成功',
      type: 'success',
      showClose: true
    });
    source.invoiceInfo = {
      titleType: 0,
      fapiaoType: 0,
      title: '',
      taxNo: '',
      address: '',
      bankAccount: '',
      bankName: '',
      phone: '',
    };
    emit('closeDialog', { type: props.type, invoiceInfo: source.invoiceInfo });    
  });
}
</script>

<style lang="scss" scoped>
.invoice-form {
  .w468 {
    width: 468px;
  }

  .invoice-header {
    display: flex;
    flex-direction: row;
    justify-content: space-between;
    align-items: center;
    width: 468px;
    height: 32px;
    border-radius: 4px;
    border: 1px solid #DCDFE6;
  }

  .default-invoice {
    display: flex;
    flex-direction: row;
    align-items: center;
    font-size: 12px;
    font-family: Microsoft YaHei-Regular, Microsoft YaHei;
    color: #3D3D3D;

    .invoice-default-icon {
      width: 16px;
      height: 16px;
      margin-right: 8px;
    }
  }

  .btns {
    display: flex;
    flex-direction: row;
    align-items: center;
    margin-top: 60px;
    width: 100%;

    .cancel-btn {
      display: flex;
      flex-direction: column;
      justify-content: center;
      align-items: center;
      width: 64px;
      height: 32px;
      background: #FFFFFF;
      border-radius: 4px;
      box-sizing: border-box;
      border: 1px solid #DCDFE6;
      font-size: 12px;
      font-family: Microsoft YaHei-Regular, Microsoft YaHei;
      color: #606266;
    }

    .confirm-btn {
      display: flex;
      flex-direction: column;
      justify-content: center;
      align-items: center;
      width: 64px;
      height: 32px;
      background: #0076F6;
      border-radius: 4px;
      font-size: 12px;
      font-family: Microsoft YaHei-Regular, Microsoft YaHei;
      color: #FFFFFF;
      margin-left: 20px;
    }

    .submit-btn {
      display: flex;
      flex-direction: column;
      justify-content: center;
      align-items: center;
      width: 321px;
      height: 40px;
      background: #0076F6;
      border-radius: 4px;
      font-size: 12px;
      font-family: Microsoft YaHei-Regular, Microsoft YaHei;
      color: #FFFFFF;
    }
  }


}
</style>
